"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CourseRoutineService = void 0;
const common_1 = require("@nestjs/common");
const mongoose_1 = require("@nestjs/mongoose");
const mongoose_2 = require("mongoose");
const courseRoutine_schema_1 = require("../schemas/courseRoutine.schema");
let CourseRoutineService = class CourseRoutineService {
    constructor(courseRoutineModel) {
        this.courseRoutineModel = courseRoutineModel;
    }
    async create(courseRoutine) {
        await this.checkCourseRoutineNameNotExists(courseRoutine.name, courseRoutine.courseId);
        const createdCourseRoutine = new this.courseRoutineModel(courseRoutine);
        return createdCourseRoutine.save();
    }
    async edit(courseRoutineId, updatedCourseRoutine) {
        await this.checkCourseRoutineNameNotExists(updatedCourseRoutine.name, updatedCourseRoutine.courseId, courseRoutineId);
        const existingCourseRoutine = await this.courseRoutineModel
            .findByIdAndUpdate(courseRoutineId, updatedCourseRoutine, {
            new: true,
        })
            .exec();
        if (!existingCourseRoutine) {
            throw new common_1.NotFoundException(`CourseRoutine with ID ${courseRoutineId} not found`);
        }
        return existingCourseRoutine;
    }
    async findAll() {
        return this.courseRoutineModel.find().exec();
    }
    async findById(courseRoutineId) {
        const courseRoutine = await this.courseRoutineModel.findById(courseRoutineId).exec();
        if (!courseRoutine) {
            throw new common_1.NotFoundException(`CourseRoutine with id ${courseRoutineId} not found`);
        }
        return courseRoutine;
    }
    async getByCourseId(courseId) {
        try {
            const courseRoutine = await this.courseRoutineModel.findOne({ courseId }).exec();
            if (!courseRoutine) {
                return null;
            }
            return courseRoutine;
        }
        catch (error) {
            throw error;
        }
    }
    async delete(courseRoutineId) {
        await this.findById(courseRoutineId);
        await this.courseRoutineModel.findByIdAndDelete(courseRoutineId).exec();
    }
    async checkCourseRoutineNameNotExists(name, courseId, excludedCourseRoutineId) {
        const existingCourseRoutine = await this.courseRoutineModel
            .findOne({ name, courseId, _id: { $ne: excludedCourseRoutineId } })
            .exec();
        if (existingCourseRoutine) {
            throw new common_1.ConflictException(`CourseRoutine "${name}" already exists for the given course`);
        }
    }
};
CourseRoutineService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, mongoose_1.InjectModel)(courseRoutine_schema_1.CourseRoutine.name)),
    __metadata("design:paramtypes", [mongoose_2.Model])
], CourseRoutineService);
exports.CourseRoutineService = CourseRoutineService;
//# sourceMappingURL=courseRoutine.service.js.map