"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnrollmentsService = void 0;
const common_1 = require("@nestjs/common");
const mongoose_1 = require("@nestjs/mongoose");
const mongoose_2 = require("mongoose");
const enrollments_schema_1 = require("../schemas/enrollments.schema");
const studentCourses_service_1 = require("./studentCourses.service");
const payment_service_1 = require("./payment.service");
const payment_schema_1 = require("../schemas/payment.schema");
const studentCourses_schema_1 = require("../schemas/studentCourses.schema");
let EnrollmentsService = class EnrollmentsService {
    constructor(enrollmentsModel, studentCoursesService, paymentService, paymentModel, studentCoursesModel) {
        this.enrollmentsModel = enrollmentsModel;
        this.studentCoursesService = studentCoursesService;
        this.paymentService = paymentService;
        this.paymentModel = paymentModel;
        this.studentCoursesModel = studentCoursesModel;
    }
    async create(enrollment) {
        const createdEnrollment = new this.enrollmentsModel(enrollment);
        const savedEnrollment = await createdEnrollment.save();
        const studentCourse = {
            enrollmentsId: savedEnrollment._id,
            courseId: enrollment.courseId,
            courseName: enrollment.courseName,
            studentId: enrollment.studentId,
            studentName: enrollment.studentName,
        };
        const paymentPayload = {
            courseId: enrollment.courseId,
            courseName: enrollment.courseName,
            studentId: enrollment.studentId,
            studentName: enrollment.studentName,
            enrollmentsId: savedEnrollment._id,
            instructorId: enrollment.instructorId,
            organizationId: enrollment.organizationId,
            paymentDate: enrollment.paymentDate,
            amount: enrollment.amount,
            discuntAmount: enrollment.discuntAmount,
            transactionType: enrollment.transactionType,
            transactionId: enrollment.transactionId,
            status: false,
        };
        await this.studentCoursesService.create(studentCourse);
        await this.paymentService.create(paymentPayload);
        return savedEnrollment;
    }
    async edit(enrollmentId, updatedEnrollment) {
        const existingEnrollment = await this.enrollmentsModel
            .findByIdAndUpdate(enrollmentId, updatedEnrollment, { new: true })
            .exec();
        if (!existingEnrollment) {
            throw new common_1.NotFoundException(`Enrollment with ID ${enrollmentId} not found`);
        }
        await this.studentCoursesService.edit({
            enrollmentsId: enrollmentId,
            courseId: updatedEnrollment.courseId,
            courseName: updatedEnrollment.courseName,
            studentId: updatedEnrollment.studentId,
            studentName: updatedEnrollment.studentName,
        });
        await this.paymentService.update({
            enrollmentsId: enrollmentId,
            courseId: updatedEnrollment.courseId,
            courseName: updatedEnrollment.courseName,
            studentId: updatedEnrollment.studentId,
            studentName: updatedEnrollment.studentName,
            instructorId: updatedEnrollment.instructorId,
            organizationId: updatedEnrollment.organizationId,
            paymentDate: updatedEnrollment.paymentDate,
            amount: updatedEnrollment.amount,
            discountAmount: updatedEnrollment.discountAmount,
            transactionType: updatedEnrollment.transactionType,
            transactionId: updatedEnrollment.transactionId,
            status: false,
        });
        return existingEnrollment;
    }
    async getAllEnrollments() {
        const enrollments = await this.enrollmentsModel.find().exec();
        const populatedEnrollments = await Promise.all(enrollments === null || enrollments === void 0 ? void 0 : enrollments.map((enrollment) => this.populateEnrollment(enrollment)));
        return populatedEnrollments;
    }
    async populateEnrollment(enrollment) {
        const payments = await this.paymentModel
            .find({ enrollmentsId: (enrollment === null || enrollment === void 0 ? void 0 : enrollment._id) || (enrollment === null || enrollment === void 0 ? void 0 : enrollment.id) })
            .exec();
        return Object.assign(Object.assign({}, enrollment.toObject()), { payments });
    }
    async getAllDetailsByEnrollmentId(enrollmentId) {
        const enrollmentDetails = await this.enrollmentsModel
            .findById(enrollmentId)
            .exec();
        if (!enrollmentDetails) {
            throw new common_1.NotFoundException(`Enrollment with ID ${enrollmentId} not found`);
        }
        const paymentDetails = await this.paymentModel
            .findOne({ enrollmentsId: enrollmentId })
            .exec();
        const studentCoursesDetails = await this.studentCoursesModel
            .findOne({ enrollmentsId: enrollmentId })
            .exec();
        return {
            enrollment: enrollmentDetails,
            payment: paymentDetails,
            studentCourses: studentCoursesDetails,
        };
    }
    async getById(enrollmentId) {
        const enrollment = await this.enrollmentsModel
            .findById(enrollmentId)
            .exec();
        if (!enrollment) {
            throw new common_1.NotFoundException(`Enrollment with ID ${enrollmentId} not found`);
        }
        return enrollment;
    }
    async getByStudentId(studentId) {
        return this.enrollmentsModel.find({ studentId }).exec();
    }
    async getByCourseId(courseId) {
        return this.enrollmentsModel.find({ courseId }).exec();
    }
    async getByInstructorId(instructorId) {
        return this.enrollmentsModel.find({ instructorId }).exec();
    }
    async getByStudentAndCourseId(courseId, studentId) {
        const enrollment = this.enrollmentsModel.findOne({ courseId, studentId }).exec();
        return enrollment || null;
    }
    async delete(enrollmentId) {
        const enrollment = await this.getById(enrollmentId);
        await Promise.all([
            this.studentCoursesService.deleteByEnrollmentId(enrollmentId),
            this.paymentService.deleteByEnrollmentId(enrollmentId),
        ]);
        await this.enrollmentsModel.findByIdAndDelete(enrollmentId).exec();
    }
    async getTotalEnrolments() {
        const total = await this.enrollmentsModel.countDocuments();
        return total;
    }
};
EnrollmentsService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, mongoose_1.InjectModel)(enrollments_schema_1.Enrollments.name)),
    __param(3, (0, mongoose_1.InjectModel)(payment_schema_1.Payment.name)),
    __param(4, (0, mongoose_1.InjectModel)(studentCourses_schema_1.StudentCourses.name)),
    __metadata("design:paramtypes", [mongoose_2.Model,
        studentCourses_service_1.StudentCoursesService,
        payment_service_1.PaymentService,
        mongoose_2.Model,
        mongoose_2.Model])
], EnrollmentsService);
exports.EnrollmentsService = EnrollmentsService;
//# sourceMappingURL=enrollments.service.js.map