"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LessonService = void 0;
const common_1 = require("@nestjs/common");
const mongoose_1 = require("@nestjs/mongoose");
const mongoose_2 = require("mongoose");
const lesson_schema_1 = require("../schemas/lesson.schema");
const cloudinary_service_1 = require("./cloudinary.service");
let LessonService = class LessonService {
    constructor(lessonModel, cloudinaryService) {
        this.lessonModel = lessonModel;
        this.cloudinaryService = cloudinaryService;
    }
    async create(lesson) {
        await this.checkLessonNameNotExists(lesson.name, lesson.sectionId);
        const createdLesson = new this.lessonModel(lesson);
        return createdLesson.save();
    }
    async edit(lessonId, updatedLesson) {
        await this.checkLessonNameNotExists(updatedLesson.name, updatedLesson.sectionId, lessonId);
        const existingLesson = await this.lessonModel
            .findByIdAndUpdate(lessonId, updatedLesson, {
            new: true,
        })
            .exec();
        if (!existingLesson) {
            throw new common_1.NotFoundException(`Lesson with ID ${lessonId} not found`);
        }
        return existingLesson;
    }
    async getAll() {
        return this.lessonModel.find().exec();
    }
    async getById(lessonId) {
        const lesson = await this.lessonModel.findById(lessonId).exec();
        if (!lesson) {
            throw new common_1.NotFoundException(`Lesson with id ${lessonId} not found`);
        }
        return lesson;
    }
    async getBySectionId(sectionId) {
        const lessons = await this.lessonModel.find({ sectionId }).exec();
        if (!lessons) {
            return null;
        }
        return lessons;
    }
    async getSectionById(sectionId) {
        return this.lessonModel.find({ sectionId, isActive: true }).exec();
    }
    async delete(lessonId) {
        await this.getById(lessonId);
        await this.lessonModel.findByIdAndDelete(lessonId).exec();
    }
    async checkLessonNameNotExists(name, sectionId, excludedLessonId) {
        const existingLesson = await this.lessonModel
            .findOne({ name, sectionId, _id: { $ne: excludedLessonId } })
            .exec();
        if (existingLesson) {
            throw new common_1.ConflictException(`Lesson ${name} already exists for the given section`);
        }
    }
    async getTotalLessons() {
        const total = await this.lessonModel.countDocuments();
        return total;
    }
};
LessonService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, mongoose_1.InjectModel)(lesson_schema_1.Lesson.name)),
    __metadata("design:paramtypes", [mongoose_2.Model,
        cloudinary_service_1.CloudinaryService])
], LessonService);
exports.LessonService = LessonService;
//# sourceMappingURL=lesson.service.js.map