"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SectionService = void 0;
const common_1 = require("@nestjs/common");
const mongoose_1 = require("@nestjs/mongoose");
const mongoose_2 = require("mongoose");
const section_schema_1 = require("../schemas/section.schema");
let SectionService = class SectionService {
    constructor(sectionModel) {
        this.sectionModel = sectionModel;
    }
    async create(sections) {
        const createdSections = [];
        for (const section of sections) {
            await this.checkSectionNameNotExists(section.name, section.courseId);
            const lastSection = await this.sectionModel
                .findOne({ courseId: section.courseId })
                .sort({ positions: -1 })
                .exec();
            section.positions = lastSection ? lastSection.positions + 1 : 1;
            const createdSection = new this.sectionModel(section);
            createdSections.push(await createdSection.save());
        }
        return createdSections;
    }
    async edit(sectionId, updatedSection) {
        await this.checkSectionNameNotExists(updatedSection.name, updatedSection.courseId, sectionId);
        const existingSection = await this.sectionModel.findByIdAndUpdate(sectionId, updatedSection, {
            new: true
        }).exec();
        if (!existingSection) {
            throw new common_1.NotFoundException(`Section with ID ${sectionId} not found`);
        }
        return existingSection;
    }
    async getAll() {
        return this.sectionModel.find().exec();
    }
    async getById(sectionId) {
        const section = await this.sectionModel.findById(sectionId).exec();
        if (!section) {
            throw new common_1.NotFoundException(`Section with id ${sectionId} not found`);
        }
        return section;
    }
    async getByCourseId(courseId) {
        const section = await this.sectionModel.find({ courseId }).exec();
        if (!section) {
            throw new common_1.NotFoundException(`Section with id ${section} not found`);
        }
        return section;
    }
    async getSectionByStatus(isActive) {
        return this.sectionModel.find({ isActive }).exec();
    }
    async getSectionByCourseIdAndStatus(courseId, isActive) {
        return this.sectionModel.find({ courseId, isActive }).exec();
    }
    async delete(sectionId) {
        await this.getById(sectionId);
        await this.sectionModel.findByIdAndDelete(sectionId).exec();
    }
    async checkSectionNameNotExists(name, courseId, excludedSectionId) {
        const existingSection = await this.sectionModel
            .findOne({ name, courseId, _id: { $ne: excludedSectionId } })
            .exec();
        if (existingSection) {
            throw new common_1.ConflictException(`Section ${name} already exists for the given course`);
        }
    }
};
SectionService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, mongoose_1.InjectModel)(section_schema_1.Section.name)),
    __metadata("design:paramtypes", [mongoose_2.Model])
], SectionService);
exports.SectionService = SectionService;
//# sourceMappingURL=section.service.js.map