import { Model } from "mongoose";
import { User, UserDocument } from "src/schemas/user.schema";
import { UserDTO } from "src/viewModel/user.dto";
import { CloudinaryService } from "./cloudinary.service";
export declare class UserService {
    private userModel;
    private readonly cloudinaryService;
    constructor(userModel: Model<UserDocument>, cloudinaryService: CloudinaryService);
    findAll(): Promise<UserDTO[]>;
    findByRoleAndStatus(role?: string, status?: boolean): Promise<User[]>;
    create(user: User): Promise<User>;
    findUser(phone: string, username: string): Promise<User | null>;
    getById(id: string): Promise<UserDTO>;
    edit(id: string, updatedUser: User): Promise<User>;
    delete(id: string): Promise<void>;
    activateUser(id: string, status: boolean): Promise<User>;
    resetPassword(id: string, newPassword: string): Promise<User>;
    loginUser(email?: string | undefined, password?: string | undefined, phone?: string | undefined): Promise<{
        accessToken: string;
        refreshToken: string;
        user: User;
    }>;
    refreshAccessToken(refreshToken: string): Promise<string>;
    getMe(id: string): Promise<User>;
    logoutUser(refreshToken: string): Promise<void>;
    private mapUserToDTO;
    private sendPasswordResetEmail;
}
